@@ -37,7 +37,6 @@
 #include <QWheelEvent>
 
 using namespace Tiled;
-using namespace Tiled::Internal;
 
 TerrainView::TerrainView(QWidget *parent)
     : QTreeView(parent)
@@ -50,7 +49,7 @@ TerrainView::TerrainView(QWidget *parent)
     setItemsExpandable(false);
     setHeaderHidden(true);
 
-    connect(mZoomable, SIGNAL(scaleChanged(qreal)), SLOT(adjustScale()));
+    connect(mZoomable, &Zoomable::scaleChanged, this, &TerrainView::adjustScale);
 }
 
 void TerrainView::setTilesetDocument(TilesetDocument *tilesetDocument)
@@ -106,14 +105,14 @@ void TerrainView::contextMenuEvent(QContextMenuEvent *event)
 
     QMenu menu;
 
-    QIcon propIcon(QLatin1String(":images/16x16/document-properties.png"));
+    QIcon propIcon(QLatin1String(":images/16/document-properties.png"));
 
     QAction *terrainProperties = menu.addAction(propIcon,
                                              tr("Terrain &Properties..."));
     Utils::setThemeIcon(terrainProperties, "document-properties");
 
-    connect(terrainProperties, SIGNAL(triggered()),
-            SLOT(editTerrainProperties()));
+    connect(terrainProperties, &QAction::triggered,
+            this, &TerrainView::editTerrainProperties);
 
     menu.exec(event->globalPos());
 }
